@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,7 +28,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <bootstrp/sstring.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 
 #define ENABLE_BYTESTRING_STREAM_OPERATORS
 #include <tools/stream.hxx>
@@ -2891,3 +2892,5 @@ BOOL StarFile::NeedsUpdate()
     }
     return FALSE;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
